@@ -9,9 +9,9 @@
 package Lemonldap::NG::Handler::Lib::ZimbraPreAuth;
 
 use strict;
-use Digest::HMAC_SHA1 qw(hmac_sha1 hmac_sha1_hex);
+use Digest::HMAC_SHA1 qw(hmac_sha1_hex);
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.6';
 
 # Overload main run method
 sub run {
